@@ -90,7 +90,6 @@ create.xlsx.report <- function(config,study.list){
     format(config$new_items$endtime, "%b %d %Y - %X"),
     .QC$script.version,
     .QC$r.version,
-    .QC$cpu.core,
     config$paths$dir_data,
     config$paths$dir_output,
     config$paths$dir_references,
@@ -101,7 +100,6 @@ create.xlsx.report <- function(config,study.list){
                 'End time',
                 'Script version',
                 'System Information',
-                'Operating CPU cores',
                 'Input directory',
                 'Output directory',
                 'References directory',
