@@ -9,8 +9,8 @@ setupLogOptions <- function(config,
   if(file.exists(log.file.path))
     file.remove(log.file.path)
 
-  flog.appender(appender.file(log.file.path), name='GWASinspector')
-
+  flog.appender(appender.file(log.file.path), name='GWASinspector_logger')
+  flog.threshold(INFO)
   return(log.file.path)
 }
 
@@ -22,30 +22,36 @@ print.and.log<-function(message,
 {
 
   if(cat & display)
+  {
     message(paste('-' , toupper(level), ' : ' , message , sep=' '))
+  }
   else if(display)
+  {
     print(message, quote= FALSE)
+  }
 
 
     if(level=='info'){
-      flog.info(message)
+      flog.info(msg =  message , name='GWASinspector_logger')
     }else if(level=='warning'){
-      flog.warn(message)
+      flog.warn(msg =  message, name='GWASinspector_logger')
     }else if(level=='fatal')
     {
-      flog.fatal(message)
+      flog.fatal(msg =  message, name='GWASinspector_logger')
       runStopCommand()
     }
 
 }
 
 
-runStopCommand<-function(message="Function is interrupted due to an error! check the log file for details.", call=FALSE)
+runStopCommand<-function(message = NULL, call=FALSE)
 {
   # this is hanldled by on.exit() command on main function
   # removeFunctionVariablesFromRAM() #terminationFunctions.r
-
-  stop(message, call. = call)
+  if(is.null(message))
+    stop("Function is interrupted due to an error! check the log file for details.", call. = call)
+  else
+    stop(message, call. = call)
 }
 
 
